@@ -676,6 +676,10 @@ class GenIce():
 
         if "cages" in lat.__dict__:
             self.cagepos, self.cagetype = parse_cages(lat.cages)
+            self.logger.warn("Use of 'cages' in a lattice-plugin is deprecated.")
+        elif "cagepos" in lat.__dict__:
+            # pre-parsed data
+            self.cagepos, self.cagetype = np.array(lat.cagepos), lat.cagetype
 
         # ================================================================
         # fixed: specify the bonds whose directions are fixed.
